@@ -17,7 +17,7 @@ from ansurr.functions import check_quiet_print
 from datetime import datetime
 
 sys.tracebacklimit = 0
-version = "0.0.21"
+version = "0.0.23"
 
 natsort = lambda s: [int(t) if t.isdigit() else t.lower() for t in re.split('(\d+)', s)]
 
@@ -112,11 +112,11 @@ def main():
         for rigidity in sorted(chain_output_rigidity[chain],key=natsort):
             if chain in chain_output_rci:
                 for rci in sorted(chain_output_rci[chain],key=natsort):
-                    compare.compare_rci_rigidity(rigidity,rci,output_dir+'/ANSURR_output/',quiet=args.quiet)
+                    compare.compare_rci_rigidity(rigidity,rci,output_dir,cyrange=args.welldef,quiet=args.quiet)
             else:
                 for rci_chain in sorted(chain_output_rci,key=natsort):
                     for rci in chain_output_rci[rci_chain]:
-                        compare.compare_rci_rigidity(rigidity,rci,output_dir+'/ANSURR_output/',quiet=args.quiet)  
+                        compare.compare_rci_rigidity(rigidity,rci,output_dir,cyrange=args.welldef,quiet=args.quiet)  
 
 
     if len(glob.glob(output_dir+'/ANSURR_output/out/*.out')) > 0:
