@@ -229,72 +229,29 @@ def rescale_RCI(RCI_score):
     RCI_score = [min(max((i-offset)/scale,0.0),1.0) for i in RCI_score]
     return RCI_score
 
-def plot(RCI, FIRST):
-    run_CYRANGE = "0"
-    helices_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'H'] # FIRST resi can be nan!
-    helices_y = [1.04]*len(helices_x)
-    strands_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'E']
-    strands_y = [1.04]*len(strands_x)
-
-    RC_residues_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['resi']) if RCI['shift_types'][i[0]] == 'RC']
-    if len(RC_residues_x) > 0:
-        RC_residues_y = [1.02]*len(RC_residues_x)
-        plt.scatter(RC_residues_x,RC_residues_y,color='black',marker="x",s=5)
-
-    if run_CYRANGE == '1':
-        welldefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '1'] # FIRST resi can be nan!
-        welldefined_y = [1.06]*len(welldefined_x)
-        illdefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '0'] # FIRST resi can be nan!
-        illdefined_y = [1.06]*len(illdefined_x)
-        plt.scatter(welldefined_x,welldefined_y,color='limegreen',s=2)
-        plt.scatter(illdefined_x,illdefined_y,color='grey',s=2)
-
-    # get range over which to plot
-    resi_range = []
-    for i in enumerate(FIRST['resi']):
-        if str(FIRST['score'][i[0]]) != 'nan' and str(RCI['score'][i[0]]) != 'nan':
-            resi_range.append(i[1])
-
-    plt.plot(RCI['resi'],RCI['score'])
-    plt.plot(FIRST['resi'],FIRST['score'])
-    plt.scatter(helices_x,helices_y,color='red',s=2)
-    plt.scatter(strands_x,strands_y,color='blue',s=2)
-    plt.xlabel('residue number',size=10)
-    plt.ylabel('flexibility',size=10)
-    plt.ylim(-0.025,1.075)
-    plt.xlim(min(resi_range)-5,max(resi_range)+5)
-    if run_CYRANGE == '1':
-        plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n All residues | Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score)+'\n Well-defined | Corr: '+"{:.3f}".format(spearman_noRC_welldefined)+' CorrScore: ' + "{:.1f}".format(corr_score_welldefined)+' RMSD: '+"{:.3f}".format(RMSD_noRC_welldefined)+' RMSDScore: ' + "{:.1f}".format(RMSD_score_welldefined),fontsize=10)
-    else:
-        plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score),fontsize=10)
-    plt.savefig(PDB_ID+'_'+SHIFT_ID+'.png',dpi=300,bbox_inches='tight')
-
 def all_same(items):
     return all(x == items[0] for x in items)
 
-
-def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
+def compare_rci_rigidity(input_first,input_rci,output_dir='',cyrange=False,quiet=False):
     
     # import data
     FIRST_in = open(input_first,'r')
     RCI_in = open(input_rci,'r')
     PDB_ID = os.path.basename(os.path.splitext(input_first)[0])
     SHIFT_ID= os.path.basename(os.path.splitext(input_rci)[0])
-    #ANSURR_PATH = sys.argv[4]
-    #run_CYRANGE = sys.argv[5]
-    run_CYRANGE = "0"
 
     CHAIN_ID='' # clunky but allows for '_' in PDB name, need to check if this is an issue anywhere else
     for i in PDB_ID.split('_')[:-1]:
         CHAIN_ID+=i+'_'
     CHAIN_ID = CHAIN_ID[-2]
 
-    if run_CYRANGE == '1':
-        with open(os.getcwd()+'/other_output/CYRANGE/cyrange.json') as json_file:
-            cyrange = json.load(json_file)
+    if cyrange:
+        with open(output_dir+'/other_output/cyrange/cyrange.json') as json_file:
+            welldefined_residues = json.load(json_file)
 
     with resources.path("ansurr.lib", "benchmarks.json") as f:
         benchmark_file_path = f
+    #benchmark_file_path = 'lib/benchmarks.json'
 
     with open(benchmark_file_path) as json_file:
         benchmarks = json.load(json_file)
@@ -340,15 +297,15 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
         except:
             FIRST['ss'].append(np.nan)
 
-    if run_CYRANGE == '1':
+    if cyrange:
         FIRST['welldefined'] = []
-        if len(cyrange) == 1:
+        if len(welldefined_residues) == 1:
             chain = 'default chain'
         else:
             chain = CHAIN_ID
 
         for resi in FIRST['resi']:
-            if resi in cyrange[chain]:
+            if resi in welldefined_residues[chain]:
                 FIRST['welldefined'].append('1')
             else:
                 FIRST['welldefined'].append('0')
@@ -392,7 +349,7 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
             spearman_noRC = spearmanr(RCI_noRC,FIRST_noRC)[0]
             corr_score = percentileofscore(benchmarks['corr'],spearman_noRC)
 
-        if run_CYRANGE == '1':
+        if cyrange:
             RCI_noRC_welldefined = [x for i,x in enumerate(RCI['score']) if i not in FIRST_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
             FIRST_noRC_welldefined = [x for i,x in enumerate(FIRST['score']) if i not in RCI_nan and not np.isnan(x) and RCI['shift_types'][i] != 'RC' and FIRST['welldefined'][i]=='1']
             
@@ -407,8 +364,6 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
             else:
                 spearman_noRC_welldefined = spearmanr(RCI_noRC_welldefined,FIRST_noRC_welldefined)[0]
                 corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
-                #corr_score_welldefined = percentileofscore(benchmarks['corr_welldefined'],spearman_noRC_welldefined)
-
 
         av_perc_shifts = int(round(np.nanmean([RCI['shifts'][i[0]] for i in enumerate(RCI['resi']) if not np.isnan(i[1])])*100.0))
 
@@ -420,11 +375,11 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
             check_quiet_print(quiet,'DONE')
             
         # write output file
-        if not os.path.exists(output_dir):
-            os.makedirs(output_dir+'figs')
-            os.makedirs(output_dir+'out')
+        if not os.path.exists(output_dir+'/ANSURR_output/'):
+            os.makedirs(output_dir+'/ANSURR_output/figs')
+            os.makedirs(output_dir+'/ANSURR_output/out')
 
-        RCI_FIRST_out = open(output_dir+'out/'+PDB_ID+'_'+SHIFT_ID+'.out','w')
+        RCI_FIRST_out = open(output_dir+'/ANSURR_output/out/'+PDB_ID+'_'+SHIFT_ID+'.out','w')
         for i in enumerate(FIRST['resi']):
 
             ss = str(FIRST['ss'][i[0]])
@@ -439,8 +394,8 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
         RCI_FIRST_out.close()
 
         # append to scores.out
-        scores = open(output_dir+'scores.out','a+')
-        if run_CYRANGE == '1':
+        scores = open(output_dir+'/ANSURR_output/scores.out','a+')
+        if cyrange:
             scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC) + ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ ' Corr-WD: '+ '{: 5.3f}'.format(spearman_noRC_welldefined)+' CorrScore-WD: '+ '{:4.1f}'.format(round(corr_score_welldefined,1)) + ' RMSD-WD: '+ '{:4.3f}'.format(RMSD_noRC_welldefined) + ' RMSDScore-WD: '+ '{:4.1f}'.format(round(RMSD_score_welldefined,1))+'\n')
         else:
             scores.write('PDB: '+ '{:<11}'.format(PDB_ID) + ' SHIFTS: '+ '{:<11}'.format(SHIFT_ID) + ' SHIFT%: '+ '{:3}'.format(av_perc_shifts) + ' Corr: '+ '{: 5.3f}'.format(spearman_noRC) + ' CorrScore: '+ '{:4.1f}'.format(round(corr_score,1)) + ' RMSD: '+ '{:4.3f}'.format(RMSD_noRC)+ ' RMSDScore: '+ '{:4.1f}'.format(round(RMSD_score,1))+ '\n')
@@ -449,6 +404,8 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
         # plot figs
         #plot(RCI,FIRST)
 
+        plt.figure()
+
         helices_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'H'] # FIRST resi can be nan!
         helices_y = [1.04]*len(helices_x)
         strands_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['ss']) if i[1] == 'E']
@@ -459,7 +416,7 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
             RC_residues_y = [1.02]*len(RC_residues_x)
             plt.scatter(RC_residues_x,RC_residues_y,color='black',marker="x",s=5)
 
-        if run_CYRANGE == '1':
+        if cyrange:
             welldefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '1'] # FIRST resi can be nan!
             welldefined_y = [1.06]*len(welldefined_x)
             illdefined_x = [FIRST['resi'][i[0]] for i in enumerate(FIRST['welldefined']) if i[1] == '0'] # FIRST resi can be nan!
@@ -473,8 +430,6 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
             if str(FIRST['score'][i[0]]) != 'nan' and str(RCI['score'][i[0]]) != 'nan':
                 resi_range.append(i[1])
 
-        plt.figure()
-
         plt.plot(RCI['resi'],RCI['score'])
         plt.plot(FIRST['resi'],FIRST['score'])
         plt.scatter(helices_x,helices_y,color='red',s=2)
@@ -483,22 +438,18 @@ def compare_rci_rigidity(input_first,input_rci,output_dir='',quiet=False):
         plt.ylabel('flexibility',size=10)
         plt.ylim(-0.025,1.075)
         plt.xlim(min(resi_range)-5,max(resi_range)+5)
-        if run_CYRANGE == '1':
+        if cyrange:
             plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n All residues | Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score)+'\n Well-defined | Corr: '+"{:.3f}".format(spearman_noRC_welldefined)+' CorrScore: ' + "{:.1f}".format(corr_score_welldefined)+' RMSD: '+"{:.3f}".format(RMSD_noRC_welldefined)+' RMSDScore: ' + "{:.1f}".format(RMSD_score_welldefined),fontsize=10)
         else:
             plt.title('structure: ' + PDB_ID + ' shifts: ' + SHIFT_ID + ' shift%: '+av_perc_shifts_out+'\n Corr: '+"{:.3f}".format(spearman_noRC)+' CorrScore: ' + "{:.1f}".format(corr_score)+' RMSD: '+"{:.3f}".format(RMSD_noRC)+' RMSDScore: ' + "{:.1f}".format(RMSD_score),fontsize=10)
-        plt.savefig(output_dir+'figs/'+PDB_ID+'_'+SHIFT_ID+'.png',dpi=300,bbox_inches='tight')
+        plt.savefig(output_dir+'/ANSURR_output/figs/'+PDB_ID+'_'+SHIFT_ID+'.png',dpi=300,bbox_inches='tight')
 
         plt.close()
 
 def main():
 
     compare_rci_rigidity(sys.argv[1],sys.argv[2])
-
-
     sys.exit(0)
-
-
-      
+   
 if __name__ == "__main__":
     main()
